Distance Matrix Computation using distance function based on T^q
dist.mat.T(X, estim.method = c("copula"), mutual = FALSE)an object of class "dist"
a data frame for vector X
An optional character string specifying a method for estimating the directed dependence coefficient.
use type B function (mutual perfect dependence) or not